"""Extension to add custom CSS for footnotes."""
from pathlib import Path

from sphinx.application import Sphinx
from sphinx.util.logging import getLogger

from ... import __version__ as core_version
from ...builders import RevealjsHTMLBuilder

here = Path(__file__).parent
logger = getLogger(__name__)


def register_extra_static_path(app: Sphinx):
    if not isinstance(app.builder, RevealjsHTMLBuilder):
        return
    app.builder.config.revealjs_static_path.append(str(here / "static"))
    app.builder.add_css_file("sphinx-revealjs/css/footnotes.css")


def register_css_context(app: Sphinx, ctx: dict):
    """Inject config values into builder's globalcontext."""
    ctx.setdefault(
        "revealjs_footnotes",
        {
            "font_size": app.config.revealjs_footnotes_font_size,
            "ref_font_size": app.config.revealjs_footnotes_ref_font_size,
        },
    )


def setup(app: Sphinx):
    """Entryoint."""
    app.add_config_value("revealjs_footnotes_font_size", "50%", "env")
    app.add_config_value("revealjs_footnotes_ref_font_size", "70%", "env")
    app.connect("builder-inited", register_extra_static_path)
    app.connect("revealjs:ready-for-writing", register_css_context)
    return {
        "version": core_version,
        "env_version": 1,
        "parallel_read_safe": True,
        "parallel_write_safe": True,
    }



"""Internal extension for Speaker view or Reveal.js."""
import html

from docutils import nodes  # type: ignore
from docutils.parsers.rst.directives.admonitions import BaseAdmonition  # type: ignore
from sphinx.application import Sphinx
from sphinx.directives import SphinxDirective
from sphinx.util.docutils import SphinxTranslator

from .. import __version__
from ..builders import RevealjsHTMLBuilder
from ..writers import not_write


class revealjs_notes(nodes.Admonition, nodes.Element):  # noqa: D101
    pass


class RevealjsNotes(BaseAdmonition, SphinxDirective):  # noqa: D101
    has_content = True
    node_class = revealjs_notes

    def run(self):  # noqa: D102
        (node,) = super().run()
        if isinstance(node, (nodes.system_message, revealjs_notes)):
            return [node]


def visit_revealjs_notes(self: SphinxTranslator, node: revealjs_notes):  # noqa: D103
    if not isinstance(self.builder, RevealjsHTMLBuilder):
        self.visit_admonition(node)
        return
    self.body.append(f'<aside class="notes">{html.escape(node.astext())}</aside>')
    raise nodes.SkipNode


def depart_revaljs_notes(self: SphinxTranslator, node: revealjs_notes):  # noqa: D103
    if not isinstance(self.builder, RevealjsHTMLBuilder):
        self.depart_admonition(node)
        return


def setup(app: Sphinx):  # noqa: D103
    app.add_node(
        revealjs_notes,
        html=(visit_revealjs_notes, depart_revaljs_notes),
        latex=(not_write, not_write),
        text=(not_write, not_write),
        man=(not_write, not_write),
        texinfo=(not_write, not_write),
        revealjs=(visit_revealjs_notes, depart_revaljs_notes),
        dirrevealjs=(visit_revealjs_notes, depart_revaljs_notes),
    )
    app.add_directive("revealjs-notes", RevealjsNotes)
    app.add_config_value("revealjs_notes_from_comments", False, "env")
    return {
        "version": __version__,
        "env_version": 2,
        "parallel_read_safe": True,
    }
